### R code from vignette source 'opm.Rnw'

###################################################
### code chunk number 1: opm.Rnw:348-351
###################################################
options(prompt = "R> ")
options(continue = "   ")
library("methods") # necessary?


###################################################
### code chunk number 2: opm.Rnw:354-356
###################################################
library("opm")
data("vaas_et_al", package = "opmdata")


###################################################
### code chunk number 3: opm.Rnw:381-382
###################################################
library("opm")


###################################################
### code chunk number 4: opm.Rnw:385-387
###################################################
(files <- opm_files("testdata"))
stopifnot(length(files) == 9) # just a check -- usually not needed


###################################################
### code chunk number 5: opm.Rnw:395-397
###################################################
summary(example.opm <- read_opm(files, include = "*Example_?.csv.xz"))
stopifnot(length(example.opm) == 3) # just a check -- usually not needed


###################################################
### code chunk number 6: opm.Rnw:408-409
###################################################
example.single <- read_single_opm(files[1])


###################################################
### code chunk number 7: opm.Rnw:413-416
###################################################
batch_opm_to_yaml(files, include = "*Example_?.csv.xz", 
  aggr.args = list(boot = 100, method = "opm-fast"), 
  outdir = ".", demo = TRUE)


###################################################
### code chunk number 8: opm.Rnw:420-423
###################################################
batch.result <- batch_opm_to_yaml(files, include = "*Example_?.csv.xz", 
  outdir = ".", 
  aggr.args = list(boot = 100, method = "opm-fast"))


###################################################
### code chunk number 9: opm.Rnw:438-439
###################################################
metadata.example <- collect_template(files, include = "*Example_?.csv.xz")


###################################################
### code chunk number 10: opm.Rnw:443-445
###################################################
collect_template(files, include = "*Example_?.csv.xz", 
  outfile = "example_metadata.csv")


###################################################
### code chunk number 11: opm.Rnw:454-455
###################################################
metadata.example <- to_metadata("example_metadata.csv")


###################################################
### code chunk number 12: opm.Rnw:463-464
###################################################
metadata.example[, "Colour"] <- c("blue", "red", "yellow")


###################################################
### code chunk number 13: opm.Rnw:467-468
###################################################
example.opm <- include_metadata(example.opm, md = metadata.example)


###################################################
### code chunk number 14: opm.Rnw:471-472
###################################################
metadata(example.opm)


###################################################
### code chunk number 15: opm.Rnw:478-479
###################################################
unlink("example_metadata.csv")


###################################################
### code chunk number 16: opm.Rnw:488-489
###################################################
(md.map <- metadata_chars(example.opm, values = FALSE))


###################################################
### code chunk number 17: opm.Rnw:495-498
###################################################
md.map["Colour"] <- "Colony colour"
example.opm <- map_metadata(example.opm, md.map, values = FALSE)
metadata(example.opm)


###################################################
### code chunk number 18: opm.Rnw:506-510
###################################################
(md.map <- metadata_chars(example.opm, values = TRUE))
md.map["red"] <- "green"
example.opm <- map_metadata(example.opm, md.map, values = TRUE)
metadata(example.opm)


###################################################
### code chunk number 19: opm.Rnw:522-523
###################################################
data("vaas_1")


###################################################
### code chunk number 20: opm.Rnw:531-532
###################################################
vaas_1.reaggr <- do_aggr(vaas_1, boot = 100, method = "opm-fast")


###################################################
### code chunk number 21: opm.Rnw:539-541
###################################################
aggr_settings(vaas_1)
aggr_settings(vaas_1.reaggr)


###################################################
### code chunk number 22: opm.Rnw:546-548
###################################################
vaas_1.aggr <- aggregated(vaas_1)
vaas_1.reaggr.aggr <- aggregated(vaas_1.reaggr)


###################################################
### code chunk number 23: opm.Rnw:564-567
###################################################
data("vaas_et_al", package = "opmdata")
vaas.small <- vaas_et_al[, , c("A01", "G11", "H11")]
dim(vaas.small)


###################################################
### code chunk number 24: opm.Rnw:582-583
###################################################
data("vaas_et_al", package = "opmdata")


###################################################
### code chunk number 25: opm.Rnw:588-589
###################################################
"Experiment" %k% vaas_et_al


###################################################
### code chunk number 26: opm.Rnw:594-595
###################################################
c("Experiment", "Species") %k% vaas_et_al


###################################################
### code chunk number 27: opm.Rnw:600-602
###################################################
c(Experiment = "First replicate", 
  Species = "Escherichia coli") %q% vaas_et_al


###################################################
### code chunk number 28: opm.Rnw:607-608
###################################################
list(Species = c("Escherichia coli", "Bacillus subtilis")) %q% vaas_et_al


###################################################
### code chunk number 29: opm.Rnw:615-617
###################################################
vaas.e.coli.1 <- vaas_et_al[c(Experiment = "First replicate", 
  Species = "Escherichia coli") %q% vaas_et_al]


###################################################
### code chunk number 30: opm.Rnw:623-625
###################################################
data("vaas_et_al", package = "opmdata")
metadata_chars(vaas_et_al, values = FALSE)


###################################################
### code chunk number 31: opm.Rnw:631-632
###################################################
metadata(vaas_et_al, "Species")


###################################################
### code chunk number 32: opm.Rnw:640-642
###################################################
vaas.1.6 <- subset(vaas_et_al, 
  query = list(Experiment = "First replicate", 'Plate number' = 6))


###################################################
### code chunk number 33: opm.Rnw:656-658
###################################################
vaas.mu <- extract(vaas_et_al, dataframe = TRUE, 
  as.labels = NULL, subset = "mu")


###################################################
### code chunk number 34: opm.Rnw:663-667
###################################################
vaas.mu <- extract(vaas_et_al, dataframe = TRUE, 
  as.labels = list("Experiment","Number of sample time point", 
    "Plate number", "Slot", "Species", "Strain", "Time point in min"),
  subset = "mu")


###################################################
### code chunk number 35: opm.Rnw:680-682
###################################################
xy_plot(vaas.1.6, main = "E. coli vs. P. aeruginosa", 
  include = list("Species", "Strain"))


###################################################
### code chunk number 36: opm.Rnw:689-691
###################################################
print(xy_plot(vaas.1.6, main = "E. coli vs. P. aeruginosa",
  include = list("Species",   "Strain")))


###################################################
### code chunk number 37: opm.Rnw:714-716
###################################################
xy_plot(vaas.1.6[, , c("A01", "G11", "H11")], 
  main = "E. coli vs. P. aeruginosa", include = list("Species", "Strain"))


###################################################
### code chunk number 38: opm.Rnw:723-726
###################################################
print(xy_plot(vaas.1.6[, , c("A01", "G11", "H11")], 
  main = "E. coli vs. P. aeruginosa",
  include = list("Species", "Strain")))


###################################################
### code chunk number 39: opm.Rnw:742-744
###################################################
level_plot(vaas.1.6, main = "E. coli vs. P. aeruginosa", 
  include = list("Species", "Strain"))


###################################################
### code chunk number 40: opm.Rnw:751-753
###################################################
print(level_plot(vaas.1.6, main = "E. coli vs. P. aeruginosa",
  include = list("Species", "Strain")))


###################################################
### code chunk number 41: opm.Rnw:779-783
###################################################
vaas.1.6.A <- extract(vaas.1.6, as.labels = list("Species", "Strain"), 
  dataframe = TRUE)
vaas.1.6.A.hm <- heat_map(vaas.1.6.A, as.labels = "Strain", 
  as.groups = "Species")


###################################################
### code chunk number 42: opm.Rnw:790-791
###################################################
print(heat_map(vaas.1.6.A, as.labels = "Strain", as.groups = "Species"))


###################################################
### code chunk number 43: opm.Rnw:810-813
###################################################
ci_plot.legend <- ci_plot(vaas.1.6[, , 1:3], 
  as.labels = list("Species", "Strain"), subset = "A", 
  legend.field = NULL, x = 150, y = 3)


###################################################
### code chunk number 44: opm.Rnw:820-822
###################################################
print(ci_plot(vaas.1.6[, , 1:3], as.labels = list("Species", "Strain"), 
  subset = "A", legend.field = NULL, x = 150, y = 3))


###################################################
### code chunk number 45: opm.Rnw:842-845
###################################################
vaas.repl <- subset(vaas_et_al, 
  query = list(Experiment = c("First replicate", "Second replicate")))
vaas.repl <- do_disc(vaas.repl)


###################################################
### code chunk number 46: opm.Rnw:858-860
###################################################
listing(vaas.repl, as.groups = NULL)
listing(vaas.repl, as.groups = list("Species"))


###################################################
### code chunk number 47: opm.Rnw:883-884
###################################################
opm_opt(css.file = grep("[.]css$", opm_files("auxiliary"), value = TRUE))


###################################################
### code chunk number 48: opm.Rnw:891-893
###################################################
vaas.html <- phylo_data(vaas.repl, format = "html",
  as.labels = list("Species", "Strain"), outfile = "vaas.html")


###################################################
### code chunk number 49: opm.Rnw:907-911
###################################################
vaas.repl <- subset(vaas_et_al, 
  query = list(Experiment = c("First replicate", "Second replicate")))
vaas.repl <- extract(vaas.repl, 
  as.labels = list("Species", "Strain", "Experiment", "Plate number"))


###################################################
### code chunk number 50: opm.Rnw:917-918
###################################################
vaas.repl.disc <- discrete(vaas.repl, range = c(0, 400))


###################################################
### code chunk number 51: opm.Rnw:924-925
###################################################
phylo_data(vaas.repl.disc, outfile = "example_replicates.epf")


###################################################
### code chunk number 52: opm.Rnw:931-932
###################################################
vaas.repl.disc <- discrete(vaas.repl, range = c(120.2, 236.6), gap = TRUE)


###################################################
### code chunk number 53: opm.Rnw:941-943
###################################################
vaas.repl.disc <- discrete(vaas.repl, range = c(120.2, 236.6), 
  gap = TRUE, middle.na = FALSE)


###################################################
### code chunk number 54: opm.Rnw:957-958
###################################################
(names <- find_substrate(c("Glutamine", "Glutamic acid")))


###################################################
### code chunk number 55: opm.Rnw:966-967
###################################################
(names <- find_substrate(c("L-Glutamine", "L-Glutamic acid"), "glob"))


###################################################
### code chunk number 56: opm.Rnw:972-973
###################################################
(names <- find_substrate(c("*L-Glutamine", "*L-Glutamic acid"), "glob"))


###################################################
### code chunk number 57: opm.Rnw:981-982
###################################################
(positions <- find_positions(names))


###################################################
### code chunk number 58: opm.Rnw:988-989
###################################################
(subst.info <- substrate_info(names))


